// Copyright (C) 2021 UOS Technology Co., Ltd.
// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#pragma once

#define ACT_NEW_FILE	        0
#define ACT_NEW_LINK	        1
#define ACT_NEW_SYMLINK	        2
#define ACT_NEW_FOLDER	        3
#define ACT_DEL_FILE	        4
#define	ACT_DEL_FOLDER	        5
#define ACT_RENAME_FILE		    6
#define ACT_RENAME_FOLDER	    7
#define ACT_RENAME_FROM_FILE	8
#define ACT_RENAME_TO_FILE	    9
#define ACT_RENAME_FROM_FOLDER	10
#define ACT_RENAME_TO_FOLDER	11
#define ACT_MOUNT	            12
#define ACT_UNMOUNT	            13